@@ -45,11 +45,13 @@
 // Maximum memory size for inter-application communication
 static const int SHARED_MEMORY_SIZE = 4096;
 
+static const unsigned int WINDOW_DEFAULT_X_SIZE = 900;
+static const unsigned int WINDOW_DEFAULT_Y_SIZE = 700;
+
+
 MainWindow::MainWindow( const QStringList& arguments )
 	: QMainWindow ( 0 ), Ui::MainWindow()
 {
-	const unsigned int WND_X_SIZE = 900;
-	const unsigned int WND_Y_SIZE = 700;
 	const unsigned int SPLT_X_SIZE = 300;
 
     m_arguments = arguments;
@@ -98,7 +100,7 @@ MainWindow::MainWindow( const QStringList& arguments )
 	setupLangEncodingMenu();
 
 	// Resize main window and dock
-	resize( WND_X_SIZE, WND_Y_SIZE );	
+    resize( WINDOW_DEFAULT_X_SIZE, WINDOW_DEFAULT_Y_SIZE );
 	m_navPanel->resize( SPLT_X_SIZE, m_navPanel->height() );
 
 	statusBar()->show();
@@ -315,11 +317,14 @@ bool MainWindow::loadFile ( const QString &loadFileName, bool call_open_page )
 
 			if ( m_ebookFile->hasFeature( EBook::FEATURE_ENCODING ) )
 				setTextEncoding( m_ebookFile->currentEncoding() );
-			
+
 			if ( call_open_page )
 				openPage( m_ebookFile->homeUrl() );
 		}
 
+        // Disable the menu if ebook format doesn't support encoding changes
+        view_Set_encoding_action->setEnabled( m_ebookFile->hasFeature( EBook::FEATURE_ENCODING ) );
+
 		if ( m_recentFiles )
 			m_recentFiles->setCurrentFile( m_ebookFilename );
 
@@ -415,10 +420,13 @@ bool MainWindow::openPage( const QUrl& url, unsigned int flags )
 		return false; // do not change the current page.
 	}
 
-	ViewWindow * vwnd = currentBrowser();
+    ViewWindow * vwnd = currentBrowser();
 
 	if ( flags & OPF_NEW_TAB )
+    {
 		vwnd = m_viewWindowMgr->addNewTab( !(flags & OPF_BACKGROUND) );
+        vwnd->setZoomFactor( currentBrowser()->zoomFactor() );
+    }
 	
 	if ( vwnd->openUrl (url) )
 	{
@@ -493,6 +501,17 @@ void MainWindow::closeFile( )
 		
 		m_currentSettings->m_window_size_x = width();
 		m_currentSettings->m_window_size_y = height();
+
+#ifdef Q_OS_WIN
+        // On Windows if the window is maximised or minimized, the WM will not restore positions/state,
+        // so we reset to default size
+        if ( isMaximized() || isMinimized() )
+        {
+            m_currentSettings->m_window_size_x = WINDOW_DEFAULT_X_SIZE;
+            m_currentSettings->m_window_size_y = WINDOW_DEFAULT_Y_SIZE;
+        }
+#endif
+
 		m_currentSettings->m_window_size_splitter = m_navPanel->width();
 
 		m_navPanel->getSettings( m_currentSettings );
@@ -561,6 +580,11 @@ bool MainWindow::parseCmdLineArgs(const QStringList& args , bool from_another_ap
             force_background = true;
         else if ( args[i] == "-novcheck" )
             disable_vcheck = true;
+        else if ( args[i] == "-v" || args[i] == "--version" )
+        {
+            printf("kchmviewer version %d.%d built at %s %s\n", APP_VERSION_MAJOR, APP_VERSION_MINOR, __DATE__, __TIME__ );
+            exit( 0 );
+        }
         else if ( args[i] == "--url" || args[i] == "-showPage" )
             open_url = args[++i];
 		else
@@ -661,6 +685,11 @@ bool MainWindow::parseCmdLineArgs(const QStringList& args , bool from_another_ap
             XSendEvent( display, DefaultRootWindow(display), False, SubstructureRedirectMask | SubstructureNotifyMask, &event );
             XMapRaised( display, win );
 #else
+            // On Windows it is not possible to activate the window of a non-active process. From MSDN:
+            // https://msdn.microsoft.com/en-us/library/windows/desktop/ms633539%28v=vs.85%29.aspx
+            //
+            // An application cannot force a window to the foreground while the user is working with another window.
+            // Instead, Windows flashes the taskbar button of the window to notify the user.
             activateWindow();
             raise();
             show();
@@ -673,7 +702,7 @@ bool MainWindow::parseCmdLineArgs(const QStringList& args , bool from_another_ap
 	return false;
 }
 
-ViewWindow * MainWindow::currentBrowser( ) const
+ViewWindow *MainWindow::currentBrowser( ) const
 {
 	return m_viewWindowMgr->current();
 }
@@ -688,7 +717,7 @@ void MainWindow::onOpenPageInNewBackgroundTab( )
 	openPage( currentBrowser()->getNewTabLink(), OPF_NEW_TAB | OPF_BACKGROUND );
 }
 
-void MainWindow::browserChanged( ViewWindow * newbrowser )
+void MainWindow::browserChanged(ViewWindow *newbrowser )
 {
 	m_navPanel->findUrlInContents( newbrowser->getOpenedPage() );
 }
@@ -1055,12 +1084,22 @@ void MainWindow::actionLocateInContentsTab()
 
 void MainWindow::actionAboutApp()
 {
-	QString abouttext = i18n( "<html><b>kchmviewer version %1.%2</b><br><br>"
-							  "Copyright (C) George Yunaev, 2004-2014<br>"
+#if QT_VERSION >= 0x050000
+    QString info = QString( "<br>Built for %1 arch using %2 ABI<br>Running on %3, Qt version %4" )
+            .arg( QSysInfo::buildCpuArchitecture() )
+            .arg( QSysInfo::buildAbi() )
+            .arg( QSysInfo::prettyProductName() )
+            .arg( qVersion() );
+#else
+    QString info = QString( "<br>Using Qt version %1") .arg( qVersion() );
+#endif
+
+    QString abouttext = i18n( "<html><b>kchmviewer version %1.%2</b>%3<br><br>"
+                              "Copyright (C) George Yunaev, 2004-2015<br>"
 							  "<a href=\"mailto:gyunaev@ulduzsoft.com\">gyunaev@ulduzsoft.com</a><br>"
 							  "<a href=\"http://www.ulduzsoft.com/kchmviewer\">http://www.ulduzsoft.com/kchmviewer</a><br><br>"
 							  "Licensed under GNU GPL license version 3.</html>" )
-								.arg(APP_VERSION_MAJOR) .arg(APP_VERSION_MINOR);
+                                .arg(APP_VERSION_MAJOR) .arg(APP_VERSION_MINOR) .arg( info );
 
 	// It is quite funny that the argument order differs
 #if defined (USE_KDE)
@@ -1223,7 +1262,14 @@ void MainWindow::setupActions()
 						  SLOT( showPrevInToc() ),
 						  SLOT( showPrevInToc() ),
 	                      Qt::ApplicationShortcut );
-	
+
+    // Copy current URL to clipboard global shortcut
+    (void) new QShortcut( QKeySequence( i18n("Ctrl+I") ),
+                          m_viewWindowMgr,
+                          SLOT( copyUrlToClipboard()),
+                          SLOT( copyUrlToClipboard()),
+                          Qt::ApplicationShortcut );
+
 	// Context menu
 	m_contextMenu = new QMenu( this );
 	
