@@ -1,25 +1,20 @@
-/**************************************************************************
- *  Kchmviewer - a portable CHM file viewer with the best support for     *
- *  the international languages                                           *
- *                                                                        *
- *  Copyright (C) 2004-2012 George Yunaev, kchmviewer@ulduzsoft.com       *
- *                                                                        *
- *  Please read http://www.kchmviewer.net/reportbugs.html if you want     *
- *  to report a bug. It lists things I need to fix it!                    *
- *                                                                        *
- *  This program is free software: you can redistribute it and/or modify  *
- *  it under the terms of the GNU General Public License as published by  *
- *  the Free Software Foundation, either version 3 of the License, or     *
- *  (at your option) any later version.                                   *
- *																	      *
- *  This program is distributed in the hope that it will be useful,       *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *  GNU General Public License for more details.                          *
- *                                                                        *
- *  You should have received a copy of the GNU General Public License     *
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>. *
- **************************************************************************/
+/*
+ *  Kchmviewer - a CHM and EPUB file viewer with broad language support
+ *  Copyright (C) 2004-2014 George Yunaev, gyunaev@ulduzsoft.com
+ *
+ *  This program is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #include <QtDebug>
 #include <QMimeData>
@@ -141,7 +136,7 @@ class ActionListModel : public QAbstractListModel
 				return 0;
 
 			QMimeData *mimeData = new QMimeData();
-			mimeData->setData( ACTION_MIME_FORMAT, m_actions[ indexes[0].row() ].toAscii() );
+            mimeData->setData( ACTION_MIME_FORMAT, m_actions[ indexes[0].row() ].toUtf8() );
 			return mimeData;
 		}
 
